@@ -66,6 +66,19 @@ std::string WrapAspell::getSuggestion (
 	const AspellWordList *suggestions = aspell_speller_suggest ( spell_checker, s.c_str(), s.size() );
 	AspellStringEnumeration *elements = aspell_word_list_elements ( suggestions );
 	const char *word = aspell_string_enumeration_next ( elements ); // no iteration req'd
+	
+	// urgent workaround: replace extended ASCII chars in suggestions with '?'
+	// tbd: determine encoding + convert suggestion to UTF-8
+	
+	char *it;
+	if (word)
+	{
+		for (it = (char *)word; *it; it++)
+		{
+			if ( *it < 0 )
+				*it = '?';
+		}
+	}
 	return (word) ? word : "----";
 }
 
